@@ -7,14 +7,19 @@ use Carp qw( croak );
 use Exporter 'import';
 use overload ();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Scalar::Util qw( blessed );
-use Specio::DeclaredAt;
 
-our @EXPORT_OK = qw( install_t_sub _STRINGLIKE );
+our @EXPORT_OK = qw( install_t_sub is_class_loaded _STRINGLIKE );
 
 sub install_t_sub {
+
+    # Specio::DeclaredAt use Specio::OO, which in turn uses
+    # Specio::Helpers. If we load this with "use" we get a cirular require and
+    # a big mess.
+    require Specio::DeclaredAt;
+
     my $caller = shift;
     my $types  = shift;
 
@@ -72,6 +77,24 @@ sub _STRING ($) {
     return defined $_[0] && !ref $_[0] && length( $_[0] ) ? $_[0] : undef;
 }
 
+# Borrowed from Types::Standard
+sub is_class_loaded {
+    my $stash = do {
+        ## no critic (TestingAndDebugging::ProhibitNoStrict)
+        no strict 'refs';
+        \%{ $_[0] . '::' };
+    };
+
+    return 1 if exists $stash->{ISA};
+    return 1 if exists $stash->{VERSION};
+
+    foreach my $globref ( values %{$stash} ) {
+        return 1 if *{$globref}{CODE};
+    }
+
+    return 0;
+}
+
 1;
 
 # ABSTRACT: Helper subs for the Specio distro
@@ -88,7 +111,7 @@ Specio::Helpers - Helper subs for the Specio distro
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 DESCRIPTION
 
